@@ -3,22 +3,38 @@ import ckan.forms
 from ckan.controllers.base import CkanBaseController
 import genshi
 from formencode.api import Invalid
-from sqlobject.main import SQLObjectNotFound
 import simplejson
+from ckan.searchquerybuilder import SearchQueryBuilder
 
 class PackageController(CkanBaseController):
 
     def index(self):
-        rev = self.repo.youngest_revision()
-        c.package_count = len(rev.model.packages)
+        c.package_count = model.Package.query.count()
         return render('package/index')
 
     def list(self, id, format='html'):
         c.format = format
-        return self._paginate_list('packages', id, 'package/list')
+        return self._paginate_list('package', id, 'package/list',
+            ['name', 'title'])
+
+    def search(self):
+        request_params = dict(request.params)
+        c.show_results = False
+        if request_params.has_key('search_terms'):
+            c.show_results = True
+            c.search_terms = request_params['search_terms']
+            request_params['q'] = request_params['search_terms']
+            mode = MockMode('package', model.Package, request_params)
+            builder = SearchQueryBuilder(mode)
+            query = builder.execute()
+            if query is None:
+                c.packages = []
+            else:
+                c.packages = query.all()
+            c.package_count = len(c.packages)
+        return render('package/search')
 
     @validate(schema=ckan.forms.PackageNameSchema(), form='new')
-    
     def new(self):
         return render('package/new')
 
@@ -26,44 +42,42 @@ class PackageController(CkanBaseController):
         c.error = ''
         c.name = ''
         schema = ckan.forms.PackageNameSchema()
-        txn = self.repo.begin_transaction()
         if not request.params.has_key('name'):
             abort(400, '400 Bad Request -- Missing name request parameter.')
         name = request.params['name']
-        try:
-            pkg = txn.model.packages.get(name)
-        except SQLObjectNotFound:
-            pass
-        else:
+        pkg = model.Package.by_name(name)
+        if pkg is not None:
             response.status_code = 409  # "409 Conflict"
             c.error = "Package name '%s' is already in use." % name
             # Todo: In-form error indication.
             return render('package/create')
         try:
+            rev = self.repo.begin_transaction()
             c.name = schema.to_python(request.params)['name']
+            pkg = model.Package(name=c.name)
+            rev.author = c.author
+            rev.message = 'Creating package %s' % c.name
+            model.repo.commit()
+            h.redirect_to(controller='package', action='edit', id=c.name)
         except Invalid, inst:
             response.status_code = 400
             c.error = "Invalid request: " + str(inst)
             return render('package/create')
-        pkg = txn.model.packages.create(name=c.name)
-        txn.author = c.author
-        txn.log_message = 'Creating package %s' % c.name
-        txn.commit()
-        if format == 'html':
-            return render('package/create')
-        elif format == 'json':
-            response.status_code = 201
-            del(response.headers['Content-Type'])
-            return ''
+        # TODO: 2008-07-09 remove once decided this is no longer needed as all
+        # now in rest api
+        # probably should do same for other json stuff in this file
+#         if format == 'html':
+#             return render('package/create')
+#         elif format == 'json':
+#             response.status_code = 201
+#             del(response.headers['Content-Type'])
+#             return ''
     
     def read(self, id, format='html'):
-        rev = self.repo.youngest_revision()
-        try:
-            pkg = rev.model.packages.get(id)
-            if not pkg:
-                raise Exception, "Package not found."
-        except:
+        pkg = model.Package.by_name(id)
+        if pkg is None:
             return self.abort404(format)
+
         schema = ckan.forms.PackageSchema()
         c.pkg = pkg
         defaults = schema.from_python(pkg)
@@ -126,11 +140,8 @@ class PackageController(CkanBaseController):
             else:
                 h.redirect_to(action='read', id=id)
         else:
-            # Just show the edit form.
-            rev = self.repo.youngest_revision()
-            try:
-                c.pkg = rev.model.packages.get(id)
-            except:
+            c.pkg = model.Package.by_name(id)
+            if c.pkg is None:
                 return self.abort404(format)
             schema = ckan.forms.PackageSchema()
             defaults = schema.from_python(c.pkg)
@@ -139,8 +150,7 @@ class PackageController(CkanBaseController):
     
     def _render_edit_form(self, value_dict):
         from formencode import htmlfill
-        rev = self.repo.youngest_revision()
-        all_licenses = list(model.License.select()) 
+        all_licenses = list(model.License.query.all()) 
         if value_dict.has_key('licenses'):
             selected = value_dict['licenses']
         else:
@@ -183,20 +193,37 @@ class PackageController(CkanBaseController):
             indict['licenses'] = [request.params['licenses']]
         else:
             indict['licenses'] = []
-        txn = self.repo.begin_transaction()
-        txn.author = c.author
+        rev = model.new_revision()
+        rev.author = c.author
         log_message = indict.get('log_message', '')
         if self._is_spam(log_message):
             error_msg = 'This commit looks like spam'
             return error_msg
-        txn.log_message = log_message
+        rev.message = log_message
         try:
-            pkg = schema.to_python(indict, state=txn)
-        except Invalid, inst:
+            pkg = schema.to_python(indict)
+        except Exception, inst:
+            model.Session.rollback()
             response.status_code = 400
             error_msg = "Invalid request: " + str(inst)
         else:
             c.pkg_name = pkg.name
-            txn.commit()
+            model.Session.commit()
         return error_msg
 
+
+class MockMode(object):
+
+    def __init__(self, register_name, register, request_data={'q': ''}):
+        self.register_name = register_name
+        self.register = register
+        self.request_data = request_data
+
+    def get_register_name(self):
+        return self.register_name
+
+    def get_register(self):
+        return self.register
+
+
+
