@@ -1,15 +1,18 @@
 from ckan.tests import *
-import ckan.models
+import ckan.model as model
 
 import cgi
 from paste.fixture import AppError
 
 class TestPackageController(TestController2):
 
+    @classmethod
     def setup_class(self):
-        repo = ckan.models.repo
-        rev = repo.youngest_revision()
-        self.anna = rev.model.packages.get('annakarenina')
+        CreateTestData.create()
+
+    @classmethod
+    def teardown_class(self):
+        CreateTestData.delete()
 
     def test_index(self):
         offset = url_for(controller='package')
@@ -37,9 +40,12 @@ class TestPackageController(TestController2):
         assert 'Packages - New' in res
 
     def test_read(self):
-        name = self.anna.name
+        name = 'annakarenina'
         offset = url_for(controller='package', action='read', id=name)
         res = self.app.get(offset)
+        # only retrieve after app has been called
+        self.anna = model.Package.by_name(name)
+        print res
         assert 'Packages - %s' % name in res
         assert name in res
         assert 'Url:' in res
@@ -67,6 +73,31 @@ class TestPackageController(TestController2):
         res = res.click(name)
         assert 'Packages - %s' % name in res
 
+    def test_search(self):
+        offset = url_for(controller='package', action='search')
+        res = self.app.get(offset)
+        assert 'Packages - Search' in res
+        self._check_search_results(res, 'anna', ['1 result', 'annakarenina'] )
+        self._check_search_results(res, 'war', ['1 result', 'warandpeace'] )
+        self._check_search_results(res, 'a', ['2 results', 'warandpeace', 'annakarenina'] )
+        self._check_search_results(res, 'n', ['2 results', 'warandpeace', 'annakarenina'] )
+        self._check_search_results(res, '', ['0 results'] )
+        self._check_search_results(res, 'z', ['0 results'] )
+        self._check_search_results(res, 'A Novel By Tolstoy', ['1 result'] )
+        self._check_search_results(res, 'title:Novel', ['1 result'] )
+        self._check_search_results(res, 'title:peace', ['0 results'] )
+        # Not working, not needed....?
+        #self._check_search_results(res, 'name:peace', ['1 result'] )
+
+    def _check_search_results(self, page, terms, requireds):
+        form = page.forms[0]
+        form['search_terms'] =  str(terms)
+        results_page = form.submit()
+        assert 'Packages - Search' in results_page, results_page
+        for required in requireds:
+            assert required in results_page, (required, results_page)
+
+
 class TestPackageControllerUpdate(TestController2):
 
     def test_update(self):
@@ -84,22 +115,26 @@ class TestPackageControllerUpdate(TestController2):
 class TestPackageControllerEdit(TestController2):
 
     def setup_method(self, method):
-        # super(TestPackageControllerEdit, self).setup_method(method)
-        txn = ckan.models.repo.begin_transaction()
-        self.editpkg_name = 'editpkgtest'
-        self.editpkg = txn.model.packages.create(name=self.editpkg_name)
-        self.editpkg.url = 'editpkgurl.com'
-        self.editpkg.notes='this is editpkg'
-        txn.commit()
+        rev = model.new_revision()
+        self.editpkg_name = u'editpkgtest'
+        self.editpkg = model.Package(name=self.editpkg_name)
+        self.editpkg.url = u'editpkgurl.com'
+        self.editpkg.notes= u'this is editpkg'
+        model.Session.commit()
+        model.Session.remove()
         offset = url_for(controller='package', action='edit', id=self.editpkg.name)
         self.res = self.app.get(offset)
+        self.newtagname = 'russian'
 
     def teardown_method(self, method):
-        # super(TestPackageControllerEdit, self).teardown_method(method)
-        rev = ckan.models.repo.youngest_revision()
-        rev.model.packages.purge(self.editpkg.name)
-        # if method == 'test_edit_2':
-            # self._teardown_test_edit2()
+        pkg = model.Package.by_name(self.editpkg.name)
+        if pkg:
+            pkg.purge()
+        tag = model.Tag.by_name(self.newtagname)
+        if tag:
+            tag.purge()
+        model.Session.commit()
+        model.Session.remove()
 
     def test_setup_ok(self):
         assert 'Packages - Edit' in self.res
@@ -121,8 +156,7 @@ class TestPackageControllerEdit(TestController2):
         res = res.follow()
         print str(self.res)
         assert 'Packages - %s' % self.editpkg_name in res
-        rev = ckan.models.repo.youngest_revision()
-        pkg = rev.model.packages.get(self.editpkg.name)
+        pkg = model.Package.by_name(self.editpkg.name)
         assert pkg.title == new_title 
         assert pkg.url == newurl
         assert pkg.download_url == new_download_url
@@ -131,7 +165,7 @@ class TestPackageControllerEdit(TestController2):
 
     def test_edit_2(self):
         # testing tag updating
-        newtags = ['russian']
+        newtags = [self.newtagname]
         tagvalues = ' '.join(newtags)
         fv = self.res.forms[0]
         fv['tags'] =  tagvalues
@@ -142,15 +176,14 @@ class TestPackageControllerEdit(TestController2):
         res = res.follow()
         print str(res)
         assert 'Packages - %s' % self.editpkg_name in res
-        rev = ckan.models.repo.youngest_revision()
-        pkg = rev.model.packages.get(self.editpkg.name)
-        assert len(pkg.tags.list()) == 1
-        outtags = [ pkg2tag.tag.name for pkg2tag in pkg.tags ]
+        pkg = model.Package.by_name(self.editpkg.name)
+        assert len(pkg.tags) == 1
+        outtags = [ tag.name for tag in pkg.tags ]
         for tag in newtags:
             assert tag in outtags 
-        # for some reason environ['REMOTE_ADDR'] is undefined when using twill
+        rev = model.Revision.youngest()
         assert rev.author == 'Unknown IP Address'
-        assert rev.log_message == exp_log_message
+        assert rev.message == exp_log_message
 
     def test_edit_preview(self):
         newurl = 'www.editpkgnewurl.com'
@@ -169,19 +202,22 @@ Hello world.
 
 
 class TestPackageControllerNew(TestController2):
-
-    def setup_class(self):
-        self.testvalues = { 'name' : 'testpkg' }
+    pkgname = u'testpkg'
 
     def teardown_class(self):
-        rev = ckan.models.repo.youngest_revision()
-        try:
-            rev.model.packages.purge(self.testvalues['name'])
-        except:
-            pass
+        # 2008-10-01 model.Sessionremove is crucial here
+        # without it pkg is not correctly torn down due to weird interference
+        # between test_create and test_new (running test_new alone everything
+        # is ok ...)
+        model.Session.remove()
+        pkg = model.Package.by_name(self.pkgname)
+        if pkg:
+            pkg.purge()
+        model.Session.commit()
+        model.Session.remove()
 
     def test_create(self):
-        offset = url_for(controller='package', action='create')
+        offset = url_for(controller='package', action='create', id=None)
         try:
             res = self.app.get(offset)
         except AppError, inst:
@@ -191,18 +227,20 @@ class TestPackageControllerNew(TestController2):
         assert "400 Bad Request -- Missing name request parameter." in error
 
     def test_new(self):
+        # TODO: test creating a package with an existing name results in error
         offset = url_for(controller='package', action='new')
         res = self.app.get(offset)
         assert 'Packages - New' in res
         fv = res.forms[0]
-        fv['name'] = self.testvalues['name']
-        res = fv.submit(status=[200])
-        assert 'Package Create' in res
-        rev = ckan.models.repo.youngest_revision()
-        pkg = rev.model.packages.get(self.testvalues['name'])
-        assert pkg.name == self.testvalues['name']
+        fv['name'] = self.pkgname
+        res = fv.submit(status=[302])
+        res = res.follow()
+        assert 'Packages - Edit' in res
+        rev = model.Revision.youngest()
+        pkg = model.Package.by_name(self.pkgname)
+        assert pkg.name == self.pkgname
         # for some reason environ['REMOTE_ADDR'] is undefined when using twill
         assert rev.author == 'Unknown IP Address'
-        exp_log_message = 'Creating package %s' % self.testvalues['name']
-        assert rev.log_message == exp_log_message
+        exp_log_message = 'Creating package %s' % self.pkgname
+        assert rev.message == exp_log_message
 
