@@ -1,8 +1,21 @@
 from ckan.tests import *
-import ckan.model
+import ckan.model as model
 
+# TODO: purge revisions after creating them
 class TestRevisionController(TestController2):
 
+    @classmethod
+    def setup_class(self):
+        model.Session.remove()
+        # rebuild db before this test as it depends delicately on what
+        # revisions exist
+        model.rebuild_db()
+        CreateTestData.create()
+
+    @classmethod
+    def teardown_class(self):
+        CreateTestData.delete()
+
     def test_link_major_navigation(self):
         offset = url_for(controller='home')
         res = self.app.get(offset)
@@ -10,13 +23,13 @@ class TestRevisionController(TestController2):
         assert 'Repository History' in res
 
     def test_paginated_list(self):
-        self.create_100_revisions()
-        revisions = list(ckan.model.repo.history())
-        revision1 = revisions[0]
-        revision2 = revisions[50]
-        revision3 = revisions[100]
-        revision4 = revisions[-1]
         try:
+            self.create_100_revisions()
+            revisions = model.repo.history()
+            revision1 = revisions[0]
+            revision2 = revisions[50]
+            revision3 = revisions[100]
+            revision4 = revisions[-1]
             # Revisions are most recent first, with first rev on last page.
             # Todo: Look at the model to see which revision is last.
             # Todo: Test for last revision on first page.
@@ -43,27 +56,26 @@ class TestRevisionController(TestController2):
             self.assert_click(res, revision3.id, 'Revision: %s' % revision3.id)
  
             # Last page.
-	    last_id = 1 + len(revisions) / 50
+            last_id = 1 + len(revisions) / 50
             offset = url_for(controller='revision', action='list', id=last_id)
             res = self.app.get(offset)
-	    try:
-                assert 'Repository History' in res
-                assert '1' in res
-                assert 'Author' in res
-                assert 'tolstoy' in res
-                assert 'Log Message' in res
-                assert 'Creating test data.' in res
-            except:
-	        print str(res)
-		raise
+
+            print str(res)
+            assert 'Repository History' in res
+            assert '1' in res
+            assert 'Author' in res
+            assert 'tolstoy' in res
+            assert 'Log Message' in res
+            assert 'Creating test data.' in res
+
         finally:
             self.purge_100_revisions()
 
     def assert_click(self, res, link_exp, res2_exp):
-        # NB: Must .click('^2$') and not just '2' as twill with otherwise
-        #     follow the second link found on the page.
         try:
-            res2 = res.click('^%s$' % link_exp)
+            # paginate links are also just numbers
+            # res2 = res.click('^%s$' % link_exp)
+            res2 = res.click(href='revision/read/%s$' % link_exp)
         except:
             print "\nThe first response (list):\n\n"
             print str(res)
@@ -86,9 +98,9 @@ class TestRevisionController(TestController2):
 
     def create_100_revisions(self):
         for i in range(0,100):
-            self.transaction_begin()
-            self.transaction.author = "Test Revision %s" % i
-            self.transaction_commit()
+            rev = model.repo.begin()
+            rev.author = "Test Revision %s" % i
+            model.repo.commit()
 
     def purge_100_revisions(self):
         pass
@@ -122,3 +134,32 @@ class TestRevisionController(TestController2):
         assert 'No revision id specified' in res
         # hmmm i have to be logged in to do proper testing 
         # TODO: come back once login is sorted out
+
+    def test_list_format_atom(self):
+        self.create_100_revisions()
+        revisions = model.repo.history()
+        revision1 = revisions[0]
+        try:
+            # Revisions are most recent first, with first rev on last page.
+            # Todo: Look at the model to see which revision is last.
+            # Todo: Test for last revision on first page.
+            # Todo: Test for first revision on last page.
+            # Todo: Test for last revision minus 50 on second page.
+            # Page 1.   (Implied id=1)
+            offset = url_for(controller='revision', action='list')
+            res = self.app.get(offset + '?format=atom')
+            print res
+            assert '<feed' in res
+            assert 'xmlns="http://www.w3.org/2005/Atom"' in res
+            assert '</feed>' in res
+            # Todo: Better test for 'days' request param.
+            #  - fake some older revisions and check they aren't included.
+            res = self.app.get(offset + '?format=atom&days=30')
+            print res
+            assert '<feed' in res
+            assert 'xmlns="http://www.w3.org/2005/Atom"' in res
+            assert '</feed>' in res
+        finally:
+            self.purge_100_revisions()
+
+
